pub struct i128;Expand description
Supported items on this integer type inside #[encrypted] code.
Implementations
Sourceimpl i128
impl i128
Sourcepub const BITS: u32 = ::core::primitive::i128::BITS
pub const BITS: u32 = ::core::primitive::i128::BITS
Mirrors the primitive’s BITS associated constant.
Sourcepub const MIN: i128 = ::core::primitive::i128::MIN
pub const MIN: i128 = ::core::primitive::i128::MIN
Mirrors the primitive’s MIN associated constant.
Sourcepub const MAX: i128 = ::core::primitive::i128::MAX
pub const MAX: i128 = ::core::primitive::i128::MAX
Mirrors the primitive’s MAX associated constant.
Sourcepub fn abs_diff(self, other: Self) -> Self
pub fn abs_diff(self, other: Self) -> Self
Computes the absolute difference between self and other.
Sourcepub fn wrapping_add(self, rhs: Self) -> Self
pub fn wrapping_add(self, rhs: Self) -> Self
Wrapping (modular) addition.
Only works on integers whose type is statically known to the interpreter.
Sourcepub fn wrapping_sub(self, rhs: Self) -> Self
pub fn wrapping_sub(self, rhs: Self) -> Self
Wrapping (modular) subtraction.
Only works on integers whose type is statically known to the interpreter.
Sourcepub fn wrapping_mul(self, rhs: Self) -> Self
pub fn wrapping_mul(self, rhs: Self) -> Self
Wrapping (modular) multiplication.
Only works on integers whose type is statically known to the interpreter.
Sourcepub fn to_le_bytes(self) -> [u8; 16]
pub fn to_le_bytes(self) -> [u8; 16]
Returns the bytes of self in little-endian order.
Only works on integers whose type is statically known to the interpreter.
Sourcepub fn to_be_bytes(self) -> [u8; 16]
pub fn to_be_bytes(self) -> [u8; 16]
Returns the bytes of self in big-endian order.
Only works on integers whose type is statically known to the interpreter.