Mxe

Struct Mxe 

pub struct Mxe { /* private fields */ }
Owner of secret data. Decrypting data owned by this owner requires participation from all nodes that comprise the MXE cluster.

Implementations

Source

impl Mxe

pub fn get() -> Self

Generate a nonce for the MXE. Used to encrypt data which can only be decrypted by the nodes that comprise the cluster attached to the given MXE.